package WebGUI::i18n::Dutch::Asset_Collaboration;
use utf8;
our $I18N = {
  'Link Description' => {
    'lastUpdated' => '1231520185',
    'message' => 'Omschrijving link'
  },
  'Link URL' => {
    'lastUpdated' => '1231520197',
    'message' => 'URL link'
  },
  'List All Links' => {
    'lastUpdated' => '1231520206',
    'message' => 'Toon alle links'
  },
  'Unsubscribe from %s' => {
    'lastUpdated' => '1275486791',
    'message' => 'Uitschrijven van %s.'
  },
  'View this message on the website' => {
    'lastUpdated' => '1308721891',
    'message' => 'Bekijk dit bericht op de website'
  },
  'You have been unsubscribed' => {
    'lastUpdated' => '1275486801',
    'message' => 'U bent uitgeschreven.'
  },
  'add' => {
    'lastUpdated' => '1147186773',
    'message' => 'Toevoegen'
  },
  'add.label' => {
    'lastUpdated' => '1166193266',
    'message' => 'Het woord "Toevoegen".'
  },
  'add.url' => {
    'lastUpdated' => '1166193018',
    'message' => 'Een URL waar een nieuwe draad kan worden toegevoegd.'
  },
  'addlink' => {
    'lastUpdated' => '1147186780',
    'message' => 'Voeg een link toe.'
  },
  'addlink.label' => {
    'lastUpdated' => '1166193277',
    'message' => 'De zin "Voeg een link toe".'
  },
  'addquestion' => {
    'lastUpdated' => '1147188028',
    'message' => 'Voeg een vraag toe.'
  },
  'addquestion.label' => {
    'lastUpdated' => '1150720026',
    'message' => 'De zin &quot;Voeg een vraag toe&quot;.'
  },
  'allow replies' => {
    'lastUpdated' => '1147188036',
    'message' => 'Sta reacties toe.'
  },
  'allow replies description' => {
    'lastUpdated' => '1147186933',
    'message' => 'Als hier niet op gereageerd mag worden, selecteer dan &#39;Nee&quot;. '
  },
  'answer' => {
    'lastUpdated' => '1147186942',
    'message' => 'Antwoord'
  },
  'answer.label' => {
    'lastUpdated' => '1150720039',
    'message' => 'Het woord &quot;Antwoord&quot;.'
  },
  'approval workflow' => {
    'lastUpdated' => '1166436710',
    'message' => 'Goedkeuringsmethode'
  },
  'approval workflow description' => {
    'lastUpdated' => '1147682164',
    'message' => 'Kies een werkstroombeheersingstype, die iedere keer dat een post toegevoegd wordt, uitgevoerd moet worden.'
  },
  'archive' => {
    'lastUpdated' => '1147685339',
    'message' => 'Archiveer'
  },
  'archive after' => {
    'lastUpdated' => '1147685354',
    'message' => 'Archiveer na'
  },
  'archive after description' => {
    'lastUpdated' => '1147685422',
    'message' => 'De tijd tussen de laatste update van een Post en het moment dat die gearchiveerd wordt.'
  },
  'ascending' => {
    'lastUpdated' => '1147685433',
    'message' => 'Stijgend'
  },
  'asset not committed' => {
    'lastUpdated' => '1222875855',
    'message' => '<h1>Fout!</h1><p>Dit collaboratiesysteem moet worden ingevoerd voordat er een nieuwe draad kan worden begonnen</p>'
  },
  'assetName' => {
    'lastUpdated' => '1147685484',
    'message' => 'Collaboratie systeem'
  },
  'attachment' => {
    'lastUpdated' => '1147187325',
    'message' => 'Bijlage'
  },
  'attachment.label' => {
    'lastUpdated' => '1150720060',
    'message' => 'Het woord &quot;Bijlage&quot;.'
  },
  'attachment.length' => {
    'lastUpdated' => '1150100824',
    'message' => '<div class="&quot;helpIndent&quot;"><div class="&quot;helpIndent&quot;"><p>De lengte in deze bijlage, in aantal bytes.</p>  </div></div>'
  },
  'attachment.path' => {
    'lastUpdated' => '1150100810',
    'message' => '<div class="&quot;helpIndent&quot;"><div class="&quot;helpIndent&quot;"><p>Het pad naar deze bijlage in het bestandssysteem.</p></div>  </div>'
  },
  'attachment.url' => {
    'lastUpdated' => '1150100794',
    'message' => '<div class="&quot;helpIndent&quot;"><div class="&quot;helpIndent&quot;"><p>De URL van deze bijlage. </p></div>  </div>'
  },
  'attachmentLoop' => {
    'lastUpdated' => '1150100778',
    'message' => '<div class="&quot;helpIndent&quot;"><p>Een object dat alle bijlagen van dit object bevat.</p></div>'
  },
  'attachment_thumbnail' => {
    'lastUpdated' => '1189122590',
    'message' => 'De URL van de thumbnail van deze bijlage. Bestanden worden weergegeven door middel van een icoon, dat hoort bij het type bestand. Afbeeldingen hebben een echte thumbnail.'
  },
  'attachments/post' => {
    'lastUpdated' => '1166436327',
    'message' => 'Aantal bijlagen per bericht'
  },
  'attachments/post description' => {
    'lastUpdated' => '1147693797',
    'message' => 'Hoeveel bijlagen kunnen er maximaal aan elke post toegevoegd worden?'
  },
  'author' => {
    'lastUpdated' => '1150100684',
    'message' => '<div class="&quot;helpIndent&quot;"><p>De gebruikersnaam van de persoon die deze post geplaatst heeft.</p></div>'
  },
  'auto subscribe to thread' => {
    'lastUpdated' => '1166436794',
    'message' => 'Automatisch inschrijven?'
  },
  'auto subscribe to thread help' => {
    'lastUpdated' => '1152540501',
    'message' => 'Als de gebruiker niet in is geschreven bij een draad, noch bij het collaboratie systeem en ze posten via email op het systeem, moeten ze dan ingeschreven worden? Als dit op &quot;Ja&quot; staat zal dit gebeuren. Let op dat deze optie alleen werkt, wanneer het &quot;Vereiste inschrijving voor email posts?&quot; veld op &quot;Nee&quot; staat.'
  },
  'avatar.url' => {
    'lastUpdated' => '1207833263',
    'message' => '<div class="&quot;&quot;&quot;helpIndent&quot;&quot;&quot;"><p>Een URL van de avatar van de eigenaar van deze post, als avatars toegestaan zijn en deze gebruiker er &amp;eacute;&amp;eacute;n heeft.</p></div>'
  },
  'back' => {
    'lastUpdated' => '1147187247',
    'message' => 'Terug'
  },
  'back.label' => {
    'lastUpdated' => '1150720075',
    'message' => 'Het woord &quot;Terug&quot;.'
  },
  'back.url' => {
    'lastUpdated' => '1207834098',
    'message' => 'Een URL terug naar het hoofdscherm van deze collaboratie asset.'
  },
  'body' => {
    'lastUpdated' => '1147695224',
    'message' => 'Body'
  },
  'body.label' => {
    'lastUpdated' => '1150724273',
    'message' => 'Het woord &quot;Body&quot;.'
  },
  'by' => {
    'lastUpdated' => '1166192434',
    'message' => 'Door'
  },
  'by.label' => {
    'lastUpdated' => '1166192448',
    'message' => 'Het woord "Door".'
  },
  'captcha label' => {
    'lastUpdated' => '1190027832',
    'message' => 'Wat staat er op deze afbeelding?'
  },
  'captcha_label' => {
    'lastUpdated' => '1259858195',
    'message' => 'Label van de captcha (anti-spam-code).'
  },
  'close' => {
    'lastUpdated' => '1147187966',
    'message' => 'Afsluiten'
  },
  'close.label' => {
    'lastUpdated' => '1150720199',
    'message' => 'Het woord &quot;Sluiten&quot;.'
  },
  'closed' => {
    'lastUpdated' => '1147187342',
    'message' => 'Afgesloten'
  },
  'closed.label' => {
    'lastUpdated' => '1150720211',
    'message' => 'Het woord &quot;Gesloten&quot;.'
  },
  'collab link' => {
    'lastUpdated' => '1150101615',
    'message' => 'De URL naar de collaboratie.'
  },
  'collaboration post list template variables title' => {
    'lastUpdated' => '1206008794',
    'message' => 'Collaborate, variabelen van het post lijst sjabloon'
  },
  'collaboration rss template title' => {
    'lastUpdated' => '1190027838',
    'message' => 'RSS collaboratie sjabloon'
  },
  'collaboration search template title' => {
    'lastUpdated' => '1190027844',
    'message' => 'Collaboratie zoek sjabloon'
  },
  'collaboration template labels title' => {
    'lastUpdated' => '1190027850',
    'message' => 'Labels voor het collaboratie sjabloon'
  },
  'collaboration template title' => {
    'lastUpdated' => '1147700267',
    'message' => 'Collaboratie sjabloon'
  },
  'collaboration unsubscribe template title' => {
    'lastUpdated' => '1275486825',
    'message' => 'Collaboratiesysteem uitschrijfsjabloon'
  },
  'collaborationAssetId' => {
    'lastUpdated' => '1189122522',
    'message' => 'De assetId van dit Samenwerk Systeem (Collaboration System). Anders dan de variabele assetId, wordt deze niet overschreven door de assetIds binnen de Threads of Posts. '
  },
  'compensation' => {
    'lastUpdated' => '1147187483',
    'message' => 'Compensatie'
  },
  'compensation.label' => {
    'lastUpdated' => '1150720232',
    'message' => 'Het woord &quot; Compensatie&quot;. '
  },
  'content' => {
    'lastUpdated' => '1150098911',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De bewerkte inhoud van deze post. </p></div>'
  },
  'content filter' => {
    'lastUpdated' => '1166436627',
    'message' => 'Inhoudfilter gebruiken?'
  },
  'content filter description' => {
    'lastUpdated' => '1207824921',
    'message' => 'Selecteer &quot;Ja&quot; voor het filteren van de inhoud van elke post in het vervangingssysteem.'
  },
  'contentType' => {
    'lastUpdated' => '1147187505',
    'message' => 'Soort inhoud'
  },
  'controls' => {
    'lastUpdated' => '1150099933',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>Een aantal ikonen waarmee deze post verwijderd of opnieuw gerangschikt kan worden.</p></div>'
  },
  'cosmetic' => {
    'lastUpdated' => '1147188002',
    'message' => 'Uiterlijk (verkeerde spelling, problemen met de format)'
  },
  'cosmetic.label' => {
    'lastUpdated' => '1150720304',
    'message' => 'Het woord &quot;Cosmetisch&quot; (verkeerde spelling, problemen met het formaat). '
  },
  'critical' => {
    'lastUpdated' => '1147957346',
    'message' => 'Kritiek (werkt meestal niet)'
  },
  'critical.label' => {
    'lastUpdated' => '1150720346',
    'message' => 'Het woord &quot;Kritiek (werkt meestal niet)&quot;.'
  },
  'date' => {
    'lastUpdated' => '1147187427',
    'message' => 'Datum'
  },
  'date posted' => {
    'lastUpdated' => '1231520240',
    'message' => 'Publicatiedatum'
  },
  'date submitted' => {
    'lastUpdated' => '1147957323',
    'message' => 'Datum toegevoegd'
  },
  'date updated' => {
    'lastUpdated' => '1147957301',
    'message' => 'Datum vernieuwd'
  },
  'date.label' => {
    'lastUpdated' => '1150720366',
    'message' => 'Het woord &quot;Datum&quot;.'
  },
  'dateSubmitted.human' => {
    'lastUpdated' => '1150099735',
    'message' => '<div class="&quot;&quot;&quot;helpIndent&quot;&quot;&quot;"><p>De datum waarop deze post was toegevoegd, in een normaal leesbaar formaat. </p></div>'
  },
  'dateUpdated.human' => {
    'lastUpdated' => '1150099768',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De datum waarop deze post voor de laatste keer is vernieuwd, in een normaal leesbaar formaat. </p></div>'
  },
  'default karma scale' => {
    'lastUpdated' => '1147957281',
    'message' => 'Standaard karmaschaal'
  },
  'default karma scale help' => {
    'lastUpdated' => '1207916801',
    'message' => 'Dit is de standaard waarde die toegekend wordt aan het karmaschaal-veld in draden. Karmaschaal is een afweegmechanisme waarmee karma gesorteerd kan worden, zodat het gebruikt kan worden voor handicaps en moeilijkheidsgraden e.d..  '
  },
  'delete' => {
    'lastUpdated' => '1147187272',
    'message' => 'Verwijderen'
  },
  'delete.label' => {
    'lastUpdated' => '1150720385',
    'message' => 'Het woord &quot;Verwijderen&quot;.'
  },
  'descending' => {
    'lastUpdated' => '1147956689',
    'message' => 'Dalend'
  },
  'description' => {
    'lastUpdated' => '1147188497',
    'message' => 'Omschrijving'
  },
  'description.label' => {
    'lastUpdated' => '1150720408',
    'message' => 'Het woord &quot;Omschrijving&quot;.'
  },
  'display last reply' => {
    'lastUpdated' => '1147707580',
    'message' => 'Laatste reactie tonen?'
  },
  'display last reply description' => {
    'lastUpdated' => '1166192366',
    'message' => 'Als hier &quot;Ja&quot; is ingesteld, zullen er sjabloon variabelen worden toegevoegd, die de laatste post kunnen tonen. '
  },
  'displayLastReply' => {
    'lastUpdated' => '1166192418',
    'message' => 'Wilt u dat de laatste reactie wordt getoond? Als dit het geval is dan worden de variabelen voor het weergeven van de laatste reactie aangemaakt.'
  },
  'docs' => {
    'lastUpdated' => '1150100613',
    'message' => '<p>De URL waar documentatie staat over het formaat, RSS 2.0, van dit bestand (optioneel veld).</p>'
  },
  'doit' => {
    'lastUpdated' => '1257328231',
    'message' => 'Een functie die waar is als er net een zoekopdracht is gegeven.'
  },
  'edit' => {
    'lastUpdated' => '1147187289',
    'message' => 'Bewerken'
  },
  'edit job' => {
    'lastUpdated' => '1147956570',
    'message' => 'Bewerk post-taak '
  },
  'edit link' => {
    'lastUpdated' => '1147187370',
    'message' => 'Bewerk link.'
  },
  'edit message' => {
    'lastUpdated' => '1147188019',
    'message' => 'Bewerk bericht.'
  },
  'edit question' => {
    'lastUpdated' => '1147187398',
    'message' => 'Bewerk vraag.'
  },
  'edit stamp' => {
    'lastUpdated' => '1166436737',
    'message' => 'Bewerkingsmelding toevoegen aan ieder bericht?'
  },
  'edit stamp description' => {
    'lastUpdated' => '1147955825',
    'message' => 'Selecteer &quot;Ja&quot; als er bij iedere post een vermelding moet staan met informatie over wanneer deze voor het laatst bewerkt is.  '
  },
  'edit submission' => {
    'lastUpdated' => '1147187415',
    'message' => 'Bewerk bijdrage.'
  },
  'edit timeout' => {
    'lastUpdated' => '1147955659',
    'message' => 'Timeout voor bewerken'
  },
  'edit timeout description' => {
    'lastUpdated' => '1147955643',
    'message' => 'Als de timeout is verlopen kan de orginele poster het bericht niet meer bewerken.'
  },
  'edit.label' => {
    'lastUpdated' => '1150720424',
    'message' => 'Het woord &quot;Bewerken&quot;.'
  },
  'edit.url' => {
    'lastUpdated' => '1150099907',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De URL waar deze post bewerkt kan worden. </p></div>'
  },
  'editForm archiveEnabled description' => {
    'lastUpdated' => '1213625504',
    'message' => 'Wanneer dit op &quot;Ja&quot; staat zullen draden na zekere tijd automatisch worden verborgen.'
  },
  'editForm archiveEnabled label' => {
    'lastUpdated' => '1213625516',
    'message' => 'Archiveren aanzetten?'
  },
  'enable avatars' => {
    'lastUpdated' => '1147955583',
    'message' => 'Avatars aanzetten?'
  },
  'enable avatars description' => {
    'lastUpdated' => '1166192710',
    'message' => 'Kies hier "Ja" om de avatars van gebruikers weer te kunnen geven in het collaboratiesysteem. Om de avatars ook daadwerkelijk te zien is het ook van belang dat het veld "Avatar" actief is in het gebruikersprofiel, gebruikers moeten een avatar-afbeelding uploaden in hun profiel en uiteraard moeten de avatar-variabelen in het template staan. 

Gebruik van avatars vermindert de snelheid van het collaboratiesysteem.'
  },
  'enable metadata' => {
    'lastUpdated' => '1189453585',
    'message' => 'Metadata beschikbaar maken in bijdragen?'
  },
  'enable metadata description' => {
    'lastUpdated' => '1207916847',
    'message' => 'Selecteer &quot;Ja&quot; om metadata beschikbaar te maken in bijdragen en om passief profielen te maken. Dit heeft een negatief effect op de performance van het Samenwerk Systeem. Metadata moet in de instellingen ingesteld zijn. '
  },
  'epochDate' => {
    'lastUpdated' => '1222875930',
    'message' => 'De datum in epoch waarop dit object gepubliceerd is, zodat het Date macro het met verschillende opmaak kan gebruiken.'
  },
  'every 10 minutes' => {
    'lastUpdated' => '1298566479',
    'message' => 'Elke 10 minuten'
  },
  'every 15 minutes' => {
    'lastUpdated' => '1298566491',
    'message' => 'Elke 15 minuten'
  },
  'every 20 minutes' => {
    'lastUpdated' => '1298566501',
    'message' => 'Elke 20 minuten'
  },
  'every 30 minutes' => {
    'lastUpdated' => '1298566509',
    'message' => 'Elke 30 minuten'
  },
  'every 5 minutes' => {
    'lastUpdated' => '1298566516',
    'message' => 'Elke 5 minuten'
  },
  'every hour' => {
    'lastUpdated' => '1298566524',
    'message' => 'Elk uur'
  },
  'every minute' => {
    'lastUpdated' => '1298566533',
    'message' => 'Elke minuut'
  },
  'every other hour' => {
    'lastUpdated' => '1298566540',
    'message' => 'Om het huur'
  },
  'every other minute' => {
    'lastUpdated' => '1298566547',
    'message' => 'Om de minuut'
  },
  'fatal' => {
    'lastUpdated' => '1147954549',
    'message' => 'Fataal (totdat het probleem is opgelost kan er niet verder gegaan worden)'
  },
  'fatal.label' => {
    'lastUpdated' => '1150720470',
    'message' => 'Het woord &quot;Fataal (er kan niet verder gegaan worden totdat dit is verholpen)&quot;'
  },
  'feed description' => {
    'lastUpdated' => '1216986707',
    'message' => 'De omschrijving van de RSS toevoer (dit komt uit de omschrijving van de collaboratie). '
  },
  'feed title' => {
    'lastUpdated' => '1150101695',
    'message' => 'De titel van de RSS toevoer (komt uit de titel van de collaboratie).'
  },
  'filter code' => {
    'lastUpdated' => '1147954514',
    'message' => 'Filter code'
  },
  'filter code description' => {
    'lastUpdated' => '1147954467',
    'message' => 'Hiermee wordt het niveau van HTML filtering ingesteld dat op elke post wordt toegepast.'
  },
  'flatLayout' => {
    'lastUpdated' => '1147954419',
    'message' => 'Plat'
  },
  'form.footer' => {
    'lastUpdated' => '1257328284',
    'message' => 'Vereiste HTML voor het be&euml;indigen van het zoekformulier.'
  },
  'form.header' => {
    'lastUpdated' => '1150101768',
    'message' => 'De benodigde HTML en Javascript voor dit formulier.'
  },
  'form.search' => {
    'lastUpdated' => '1150101813',
    'message' => 'Een knop die aan het formulier toegevoegd kan worden om te beginnen met zoeken.'
  },
  'full text link' => {
    'lastUpdated' => '1150101863',
    'message' => 'De URL naar de volledige tekst van dit object.'
  },
  'generator' => {
    'lastUpdated' => '1150100544',
    'message' => '<p>Het programma dat de RSS toevoer genereert, oftewel WebGUI plus de versie informatie (optioneel veld).</p>'
  },
  'get cs mail' => {
    'lastUpdated' => '1147953586',
    'message' => 'Haal de mail van het collaboratiesysteem op.'
  },
  'get mail' => {
    'lastUpdated' => '1166436826',
    'message' => 'Email ophalen?'
  },
  'get mail help' => {
    'lastUpdated' => '1147954289',
    'message' => 'Moet het collaboratiesysteem posts van een email account ophalen?'
  },
  'get mail interval' => {
    'lastUpdated' => '1166436889',
    'message' => 'Controleer email elke'
  },
  'get mail interval help' => {
    'lastUpdated' => '1147953622',
    'message' => 'Hoe vaak moet er op de server gekeken worden of er nieuwe mail is?'
  },
  'group to edit hoverhelp' => {
    'lastUpdated' => '1269423245',
    'message' => 'De groep die posts mag wijzigen, nadat deze zijn geplaatst.'
  },
  'group to edit label' => {
    'lastUpdated' => '1207294876',
    'message' => 'Wijzig posts groep'
  },
  'guid' => {
    'lastUpdated' => '1150100723',
    'message' => '<div class="&quot;helpIndent&quot;"><p>De unieke identificatie van dit item.</p></div>'
  },
  'has posted to one of your subscriptions' => {
    'lastUpdated' => '1231520313',
    'message' => 'heeft gereageerd op &eacute;&eacute;n van uw forumonderwerpen.'
  },
  'hideProfileUrl' => {
    'lastUpdated' => '1254902274',
    'message' => 'Een functie die waar is als degene die post een bezoeker is of als de huidige gebruiker een bezoeker is. In het eerste geval is het bezoekers profiel niet zichtbaar. In het tweede geval kan de bezoeker geen profielen bekijken.'
  },
  'id' => {
    'lastUpdated' => '1150098818',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De AssetId van deze post. </p></div>'
  },
  'image' => {
    'lastUpdated' => '1147187444',
    'message' => 'Afbeelding'
  },
  'image.label' => {
    'lastUpdated' => '1150720488',
    'message' => 'Het woord &quot;Afbeelding&quot;.'
  },
  'image.url' => {
    'lastUpdated' => '1150099689',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>Als deze post bijlagen&nbsp; heeft, is dit de URL van de eerste afbeelding die in de bijlage zit. </p></div>'
  },
  'isFifth' => {
    'lastUpdated' => '1207832529',
    'message' => '<div class="&quot;&quot;&quot;helpIndent&quot;&quot;&quot;"><p>Een voorwaarde die aangeeft of deze post de vijde is in deze collaboratie asset.</p></div>'
  },
  'isFourth' => {
    'lastUpdated' => '1207832541',
    'message' => '<div class="&quot;&quot;&quot;helpIndent&quot;&quot;&quot;"><p>Een voorwaarde die aangeeft of deze post de vierde is in deze collaboratie asset.</p></div>'
  },
  'isSecond' => {
    'lastUpdated' => '1207832552',
    'message' => '<div class="&quot;&quot;&quot;helpIndent&quot;&quot;&quot;"><p>Een voorwaarde die aangeeft of deze post de tweede is in deze collaboratie asset.</p></div>'
  },
  'isThird' => {
    'lastUpdated' => '1207832564',
    'message' => '<div class="&quot;&quot;&quot;helpIndent&quot;&quot;&quot;"><p>Een voorwaarde die aangeeft of deze post de derde is in deze collaboratie asset.</p></div>'
  },
  'item description' => {
    'lastUpdated' => '1150101884',
    'message' => 'Een samenvatting van het object.'
  },
  'item_loop' => {
    'lastUpdated' => '1150100664',
    'message' => '<p>Dit loopt herhaaldelijk over de posts die verzonden worden in deze RSS toevoer.</p>'
  },
  'job description' => {
    'lastUpdated' => '1147953556',
    'message' => 'Taakomschrijving'
  },
  'job requirements' => {
    'lastUpdated' => '1147953534',
    'message' => 'Taak vereisten'
  },
  'job title' => {
    'lastUpdated' => '1147953511',
    'message' => 'Titel van de taak'
  },
  'job.description.label' => {
    'lastUpdated' => '1150720521',
    'message' => 'De zinssnede &quot; Taak omschrijving&quot;. '
  },
  'job.header.label' => {
    'lastUpdated' => '1150724369',
    'message' => 'De zinsnede &quot;Bewerk taak invoer&quot;.'
  },
  'job.requirements.label' => {
    'lastUpdated' => '1150720836',
    'message' => 'De zinssnede &quot;Taak vereisten&quot;.'
  },
  'job.title.label' => {
    'lastUpdated' => '1150720878',
    'message' => 'De term &quot;Naam van de taak&quot;. '
  },
  'karma rank' => {
    'lastUpdated' => '1147707560',
    'message' => 'Karma rang'
  },
  'karma rating multiplier' => {
    'lastUpdated' => '1147951204',
    'message' => 'Karma voor poster bij waardering'
  },
  'karma rating multiplier description' => {
    'lastUpdated' => '1147951051',
    'message' => 'Dit is de hoeveelheid karma die de auteur ontvangt, wanneer een andere gebruiker de post waardeert. Dit kan alleen als karma aangezet is. '
  },
  'karma scale' => {
    'lastUpdated' => '1147950981',
    'message' => 'Karma schaal'
  },
  'karma spent to rate' => {
    'lastUpdated' => '1147950966',
    'message' => 'Verbruik karma per waardering'
  },
  'karma spent to rate description' => {
    'lastUpdated' => '1147951082',
    'message' => 'Deze hoeveelheid karma wordt afgetrokken van een gebruiker bij het waarderen van een post. De achtergrond is dat gebruikers niet willekeurig alle posts gaan waarderen, zonder er over na te denken. Dit kan alleen als karma op deze site is aangezet. '
  },
  'karma/post' => {
    'lastUpdated' => '1147950783',
    'message' => 'Karma per post'
  },
  'karma/post description' => {
    'lastUpdated' => '1147950766',
    'message' => 'De hoeveelheid karma die per bijgedragen post toegevoegd wordt, als karma aangezet is.'
  },
  'karmaIsEnabled' => {
    'lastUpdated' => '1150101315',
    'message' => '<p>Een indicator die aangeeft of het gebruik van karma aanstaat of niet.</p>'
  },
  'karmaRank.label' => {
    'lastUpdated' => '1257328324',
    'message' => 'De zinsnede "Karma rang".'
  },
  'karmascale.label' => {
    'lastUpdated' => '1257328345',
    'message' => 'De zinsnede "Karma schaal".'
  },
  'keywords label' => {
    'lastUpdated' => '1219727709',
    'message' => 'Trefwoorden'
  },
  'keywords.label' => {
    'lastUpdated' => '1257328360',
    'message' => 'Het woord "Trefwoorden".'
  },
  'lastBuildDate' => {
    'lastUpdated' => '1207901865',
    'message' => '<p>De datum waarop deze toevoer het laatst is vernieuwd (optioneel veld). </p>'
  },
  'lastReply' => {
    'lastUpdated' => '1147950701',
    'message' => 'Laatste reactie'
  },
  'lastReply.dateSubmitted.human' => {
    'lastUpdated' => '1150100239',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De datum waarop het laatste antwoord was toegevoegd, in een normaal leesbaar formaat.</p></div>'
  },
  'lastReply.hideProfileUrl' => {
    'lastUpdated' => '1254902308',
    'message' => 'Een functie die waar is als de poster van de laatste post een bezoeker is of als de huidige gebruiker een bezoeker is. In het eerste geval is het bezoekers profiel niet zichtbaar. In het tweede geval kan de bezoeker geen profielen bekijken.'
  },
  'lastReply.label' => {
    'lastUpdated' => '1150720902',
    'message' => 'De term &quot;Laatste reactie&quot;.'
  },
  'lastReply.timeSubmitted.human' => {
    'lastUpdated' => '1150100256',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De tijd waarop het laatste antwoord was toegevoegd, in een normaal leesbaar formaat. </p>  </div>'
  },
  'lastReply.title' => {
    'lastUpdated' => '1150100141',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De titel van het laatste antwoord.</p></div>'
  },
  'lastReply.url' => {
    'lastUpdated' => '1150100120',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De URL van het laatste antwoord op deze post.</p></div>'
  },
  'lastReply.user.isVisitor' => {
    'lastUpdated' => '1150100168',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>Een conditionele functie die &quot;waar&quot; geeft als de plaatser van het laatste antwoord een bezoeker is.</p></div>'
  },
  'lastReply.userProfile.url' => {
    'lastUpdated' => '1207833386',
    'message' => '<div class="&quot;&quot;&quot;helpIndent&quot;&quot;&quot;"><p>The URL to the Profile of the User who submitted this Post.</p></div>'
  },
  'lastReply.username' => {
    'lastUpdated' => '1207833354',
    'message' => '<div class="&quot;&quot;&quot;helpIndent&quot;&quot;&quot;"><p>De naam van de gebruiker die het laatste antwoord heeft gegeven.</p></div>'
  },
  'layout' => {
    'lastUpdated' => '1147187317',
    'message' => 'Layout'
  },
  'layout.flat.label' => {
    'lastUpdated' => '1150720928',
    'message' => 'Het woord &quot;Plat&quot;.'
  },
  'layout.label' => {
    'lastUpdated' => '1150720947',
    'message' => 'Het woord &quot;Layout&quot;.'
  },
  'layout.nested.label' => {
    'lastUpdated' => '1150720970',
    'message' => 'Het woord &quot;Genest&quot;.'
  },
  'link.header.label' => {
    'lastUpdated' => '1150721004',
    'message' => 'De term &quot;Bewerk link&quot;.  '
  },
  'location' => {
    'lastUpdated' => '1147187671',
    'message' => 'Locatie'
  },
  'location.label' => {
    'lastUpdated' => '1150721026',
    'message' => 'Het woord &quot;Locatie&quot;.'
  },
  'lock' => {
    'lastUpdated' => '1147707856',
    'message' => 'Vergrendelen'
  },
  'lock.label' => {
    'lastUpdated' => '1150723122',
    'message' => 'Het woord &quot;Afsluiten&quot;.'
  },
  'mail' => {
    'lastUpdated' => '1166436847',
    'message' => 'Email'
  },
  'mail account' => {
    'lastUpdated' => '1147707754',
    'message' => 'Account'
  },
  'mail account help' => {
    'lastUpdated' => '1147950685',
    'message' => 'De naam van de account (gebruikersnaam of email adres), waarmee ingelogd kan worden op de mail server.'
  },
  'mail address' => {
    'lastUpdated' => '1166436857',
    'message' => 'Emailadres'
  },
  'mail address help' => {
    'lastUpdated' => '1147707811',
    'message' => 'Het email adres waar gebruikers berichten naartoe kunnen sturen, zodat ze berichten kunnen posten'
  },
  'mail password' => {
    'lastUpdated' => '1147707592',
    'message' => 'Wachtwoord'
  },
  'mail password help' => {
    'lastUpdated' => '1147707633',
    'message' => 'Het wachtwoord waarmee op de server ingelogd kan worden.'
  },
  'mail prefix' => {
    'lastUpdated' => '1147707662',
    'message' => 'Voorvoegsel'
  },
  'mail prefix help' => {
    'lastUpdated' => '1147707741',
    'message' => 'Dit zal voor het onderwerp gezet worden bij alle uit dit collaboratie systeem gezonden emails.'
  },
  'mail server' => {
    'lastUpdated' => '1147187539',
    'message' => 'Server'
  },
  'mail server help' => {
    'lastUpdated' => '1147707501',
    'message' => 'De hostnaam of IP adres van de mail server waar de email vandaan gehaald wordt.'
  },
  'max image size' => {
    'lastUpdated' => '1166192523',
    'message' => 'Maximale afbeeldingsgrootte'
  },
  'max image size help' => {
    'lastUpdated' => '1166192680',
    'message' => 'U kunt de maximale afbeeldingsgrootte bepalen. Het origineel wordt dan verkleind. Als u de waarde op 0 laat staan dan wordt de afbeelding verkleind tot de grootte die u voor de gehele website heeft ingesteld. 
<p>Let op!<br />
Nadat u deze instelling wijzigt worden niet alle  bestaande foto\'s opnieuw verkleind. Hiervoor dient u het bericht te wijzigen en opnieuw op te slaan.

'
  },
  'message' => {
    'lastUpdated' => '1147187725',
    'message' => 'Bericht'
  },
  'message.header.label' => {
    'lastUpdated' => '1150723145',
    'message' => 'De term &quot;Bewerk bericht&quot;.'
  },
  'message.label' => {
    'lastUpdated' => '1150723163',
    'message' => 'Het woord &quot;Bericht&quot;.'
  },
  'minor' => {
    'lastUpdated' => '1147950628',
    'message' => 'Klein (vervelend, maar niet schadelijk)'
  },
  'minor.label' => {
    'lastUpdated' => '1150723343',
    'message' => 'Het woord &quot;Klein (vervelend, maar niet schadelijk)&quot;.'
  },
  'nested' => {
    'lastUpdated' => '1147954481',
    'message' => 'Vertakt'
  },
  'new window' => {
    'lastUpdated' => '1147707389',
    'message' => 'Openen in nieuw venster?'
  },
  'newWindow.label' => {
    'lastUpdated' => '1150723381',
    'message' => 'De vraag &quot;Openen in nieuw venster?&quot;.'
  },
  'next' => {
    'lastUpdated' => '1147187574',
    'message' => 'Volgende'
  },
  'next.label' => {
    'lastUpdated' => '1207901580',
    'message' => 'Het woord &quot;Volgende&quot;.'
  },
  'no user email error message' => {
    'lastUpdated' => '1275486848',
    'message' => 'Er is geen gebruiker met dit e-mailadres gevonden.'
  },
  'notification template' => {
    'lastUpdated' => '1168959977',
    'message' => 'Collaboratie systeem, notificatie sjabloon'
  },
  'notification template description' => {
    'lastUpdated' => '1147706162',
    'message' => 'Het sjabloon dat gebruikt wordt voor het aanmaken van emails naar gebruikers die zich voor deze asset hebben ingeschreven.'
  },
  'once per day' => {
    'lastUpdated' => '1298566560',
    'message' => 'Eens per dag'
  },
  'open' => {
    'lastUpdated' => '1147187690',
    'message' => 'Open'
  },
  'open.label' => {
    'lastUpdated' => '1150723413',
    'message' => 'Het woord &quot;Open&quot;.'
  },
  'post' => {
    'lastUpdated' => '1147706062',
    'message' => 'Post'
  },
  'post received template' => {
    'lastUpdated' => '1222875953',
    'message' => '<p>Post ontvangen sjabloon </p>'
  },
  'post received template hoverHelp' => {
    'lastUpdated' => '1222875987',
    'message' => 'Het sjabloon dat gebruikt wordt om aan de gebruiker te melden dat de post ontvangen is.'
  },
  'post template' => {
    'lastUpdated' => '1168960052',
    'message' => 'Collaboratie systeem, formulier sjabloon'
  },
  'post template description' => {
    'lastUpdated' => '1147706033',
    'message' => 'Het sjabloon voor een enkele post '
  },
  'post title' => {
    'lastUpdated' => '1150101834',
    'message' => 'De titel van dit object (post).'
  },
  'post.label' => {
    'lastUpdated' => '1150723432',
    'message' => 'Het woord &quot;Post&quot;.'
  },
  'post_loop' => {
    'lastUpdated' => '1150098761',
    'message' => '<p>Een lijst met posts in deze collaboratie asset.</p>'
  },
  'post_loop_user.isVisitor' => {
    'lastUpdated' => '1254902331',
    'message' => 'Een functie die waar is als de poster een bezoeker is.'
  },
  'posts/page' => {
    'lastUpdated' => '1166436598',
    'message' => 'Reacties per bericht'
  },
  'posts/page description' => {
    'lastUpdated' => '1207824814',
    'message' => 'Het aantal posts op elke pagina in het draad sjabloon. Als dit aantal erg hoog is, kan het genereren van de pagina vertraagd worden.'
  },
  'preview' => {
    'lastUpdated' => '1147705935',
    'message' => 'Voorvertoning'
  },
  'previous' => {
    'lastUpdated' => '1147705920',
    'message' => 'Vorige'
  },
  'previous.label' => {
    'lastUpdated' => '1150723455',
    'message' => 'Het woord &quot;Vorige&quot;.'
  },
  'pubDate' => {
    'lastUpdated' => '1150100744',
    'message' => '<div class="&quot;helpIndent&quot;"><p>De datum waarop het object gepubliceerd is.</p></div>'
  },
  'query.form' => {
    'lastUpdated' => '1150102351',
    'message' => 'HTML formulier waarmee een veld wordt toegevoegd, waarvan alle invoer gelijk moet zijn aan die in de paginas. '
  },
  'question' => {
    'lastUpdated' => '1147705906',
    'message' => 'Vraag'
  },
  'question.header.label' => {
    'lastUpdated' => '1150723610',
    'message' => 'De zinsnede &quot;Bewerk vraag&quot;.'
  },
  'question.label' => {
    'lastUpdated' => '1150723623',
    'message' => 'Het woord &quot;Vraag&quot;.'
  },
  'rate' => {
    'lastUpdated' => '1147705888',
    'message' => 'Snelheid'
  },
  'rate.label' => {
    'lastUpdated' => '1150723642',
    'message' => 'Het woord &quot;Snelheid&quot;.'
  },
  'rating' => {
    'lastUpdated' => '1147705875',
    'message' => 'Stand'
  },
  'rating.label' => {
    'lastUpdated' => '1150723670',
    'message' => 'het woord &quot;Stand&quot;.'
  },
  'rating_loop' => {
    'lastUpdated' => '1207831977',
    'message' => '<div class="&quot;&quot;&quot;helpIndent&quot;&quot;&quot;"><p>Een proces (<em>en:</em>loop) dat voor iedere score van een post draait. </p></div>'
  },
  'rating_loop.count' => {
    'lastUpdated' => '1150098887',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><div class="&quot;&quot;helpIndent&quot;&quot;"><p>De teller van de <strong>rating_loop</strong>. </p>  </div></div>'
  },
  'read more' => {
    'lastUpdated' => '1150723583',
    'message' => 'Lees verder'
  },
  'readmore.label' => {
    'lastUpdated' => '1150723566',
    'message' => 'De zinsnede &quot;Lees verder&quot;.'
  },
  'rejected' => {
    'lastUpdated' => '1147705832',
    'message' => 'Afgekeurd'
  },
  'rejected because no user account' => {
    'lastUpdated' => '1147705791',
    'message' => 'Het is u niet toegestaan berichten te posten, aangezien we uw gebruikers account niet konden vinden. Misschien is dit email adres niet gekoppeld aan uw gebruikers account.'
  },
  'rejected because not allowed' => {
    'lastUpdated' => '1147705719',
    'message' => 'Het is u niet toegestaan berichten te posten, wegens een tekort aan rechten of omdat u niet ingeschrijven bent voor deze discussie.   '
  },
  'replies' => {
    'lastUpdated' => '1147705653',
    'message' => 'Antwoorden'
  },
  'replies.label' => {
    'lastUpdated' => '1150723693',
    'message' => 'Het woord &quot;Antwoorden&quot;.'
  },
  'reply' => {
    'lastUpdated' => '1147705641',
    'message' => 'Antwoord'
  },
  'reply filter code' => {
    'lastUpdated' => '1242725145',
    'message' => 'Antwoord filter code'
  },
  'reply filter code description' => {
    'lastUpdated' => '1242725195',
    'message' => 'Bepaald wat voor soort HTML filtering er gedaan wordt op elk antwoord bericht'
  },
  'reply rich editor' => {
    'lastUpdated' => '1242725292',
    'message' => 'Antwoord bericht Rich Editor'
  },
  'reply rich editor description' => {
    'lastUpdated' => '1242725264',
    'message' => 'Selecteer welke Rich Editor er gebruikt wordt voor de antwoord berichten.'
  },
  'reply.label' => {
    'lastUpdated' => '1150723710',
    'message' => 'Het woord &quot;Antwoord&quot;.'
  },
  'require subscription for email posting' => {
    'lastUpdated' => '1166436810',
    'message' => 'Inschrijving vereist?'
  },
  'require subscription for email posting help' => {
    'lastUpdated' => '1207825062',
    'message' => 'Als dit op &quot;Ja &quot; staat, is de gebruiker niet enkel&nbsp; verplicht in de groep te zitten, maar moet ook bij het collaboratie systeem of de draad ingeschreven staan om erin te kunnen posten. '
  },
  'responses' => {
    'lastUpdated' => '1147187957',
    'message' => 'Reacties'
  },
  'responses.label' => {
    'lastUpdated' => '1150723730',
    'message' => 'Het woord &quot;Reacties&quot;.'
  },
  'rich editor' => {
    'lastUpdated' => '1147705628',
    'message' => 'Rich editor'
  },
  'rich editor description' => {
    'lastUpdated' => '1206008906',
    'message' => 'Selecteer de Rich editor die gebruikt wordt voor posts. '
  },
  'rss template' => {
    'lastUpdated' => '1168960074',
    'message' => 'Collaboratie systeem, RSS sjabloon'
  },
  'rss template description' => {
    'lastUpdated' => '1147705254',
    'message' => 'Het sjabloon dat in deze asset gebruikt wordt om de XML voor een RSS toevoer te genereren.'
  },
  'rss.url' => {
    'lastUpdated' => '1150101215',
    'message' => '<p>Een URL waar de RSS samenvatting van deze asset gedownload kan worden. </p>'
  },
  'search' => {
    'lastUpdated' => '1150723784',
    'message' => 'Zoeken'
  },
  'search template' => {
    'lastUpdated' => '1168960095',
    'message' => 'Collaboratie systeem, zoek sjabloon'
  },
  'search template description' => {
    'lastUpdated' => '1147705141',
    'message' => 'Het sjabloon voor de zoekfunctie van deze collaboratie asset.'
  },
  'search.label' => {
    'lastUpdated' => '1150723754',
    'message' => 'Het woord &quot;Zoeken&quot;.'
  },
  'search.url' => {
    'lastUpdated' => '1150101239',
    'message' => '<p>Een URL waar het zoekformulier van deze collaboratie asset gevonden kan worden. </p>'
  },
  'sequence' => {
    'lastUpdated' => '1147705098',
    'message' => 'Reeks'
  },
  'severity' => {
    'lastUpdated' => '1147705069',
    'message' => 'Graad'
  },
  'severity.label' => {
    'lastUpdated' => '1150723799',
    'message' => 'Het woord &quot;Graad&quot;.'
  },
  'sort by' => {
    'lastUpdated' => '1147704887',
    'message' => 'Sorteer op'
  },
  'sort by description' => {
    'lastUpdated' => '1276684394',
    'message' => 'Alle posts worden standaard in een bepaalde volgorde gesorteerd. Gebruik dit veld om de eigenschap waarop ze gesorteerd worden te kiezen.'
  },
  'sort order' => {
    'lastUpdated' => '1166436643',
    'message' => 'Sortering'
  },
  'sort order description' => {
    'lastUpdated' => '1147704785',
    'message' => 'Sorteer in stijgende of dalende volgorde.'
  },
  'sortby.date.url' => {
    'lastUpdated' => '1207833817',
    'message' => '<p>Een URL waar de lijst met posts op de datum waarop ze toegevoegd zijn gesorteerd getoond kunnen worden. </p>'
  },
  'sortby.karmaRank.url' => {
    'lastUpdated' => '1207833843',
    'message' => '<p>Een URL waar de lijst met posts gesorteerd getoond kan worden op volgorde van de hoeveelheid karma die gebruikers aan de draad hebben toegevoegd.</p>'
  },
  'sortby.lastreply.url' => {
    'lastUpdated' => '1207833909',
    'message' => '<p>Een URL waar de lijst met posts op de datum waarop ze het laatst zijn vernieuwd gesorteerd getoond kunnen worden.</p>'
  },
  'sortby.rating.url' => {
    'lastUpdated' => '1207833875',
    'message' => '<p>Een URL waar de lijst met posts op hun waardering gesorteerd getoond kunnen worden.    </p>'
  },
  'sortby.replies.url' => {
    'lastUpdated' => '1207833934',
    'message' => '<p>Een URL waar de lijst met posts op het aantal reacties gesorteerd getoond kunnen worden.    </p>'
  },
  'sortby.title.url' => {
    'lastUpdated' => '1207833863',
    'message' => '<p>Een URL waar de lijst met posts op titel gesorteerd getoond kunnen worden.</p>'
  },
  'sortby.username.url' => {
    'lastUpdated' => '1207833729',
    'message' => '<p>Een URL waar de lijst met posts op gebruikersnaam gesorteerd getoond kunnen worden.</p>'
  },
  'sortby.views.url' => {
    'lastUpdated' => '1207833770',
    'message' => '<p>Een URL waar de lijst met posts op het aantal bezichtigingen gesorteerd getoond kunnen worden. </p>'
  },
  'status' => {
    'lastUpdated' => '1147704761',
    'message' => 'Status'
  },
  'status.label' => {
    'lastUpdated' => '1150723820',
    'message' => 'Het woord &quot;Status&quot;.'
  },
  'stick.label' => {
    'lastUpdated' => '1150723876',
    'message' => 'De zinsnede &quot;Zet bovenaan&quot;.'
  },
  'sticky' => {
    'lastUpdated' => '1147704751',
    'message' => 'Zet bovenaan'
  },
  'subject' => {
    'lastUpdated' => '1147187747',
    'message' => 'Onderwerp'
  },
  'subject.label' => {
    'lastUpdated' => '1150723894',
    'message' => 'Het woord &quot;Onderwerp&quot;.'
  },
  'submission.header.label' => {
    'lastUpdated' => '1150723939',
    'message' => 'De zinsnede &quot;Bewerk bijdrage&quot;.'
  },
  'subscribe' => {
    'lastUpdated' => '1147704738',
    'message' => 'Inschrijven'
  },
  'subscribe.label' => {
    'lastUpdated' => '1150723956',
    'message' => 'Het woord &quot;Inschrijven&quot;.'
  },
  'subscribe.url' => {
    'lastUpdated' => '1207833578',
    'message' => '<p>Een URL die de huidige gebruiker kan inschrijven bij deze collaboratie asset. De gebruiker wordt op de hoogte gehouden van nieuwe inhoud in de asset. </p>'
  },
  'subscription group hoverHelp' => {
    'lastUpdated' => '1190027992',
    'message' => 'Beheer de gebruikers met een abonnement op dit Collaboration System'
  },
  'subscription group label' => {
    'lastUpdated' => '1190027950',
    'message' => 'Groep om bijdragen per email te ontvangen'
  },
  'synopsis' => {
    'lastUpdated' => '1147704727',
    'message' => 'Samenvatting'
  },
  'synopsis.label' => {
    'lastUpdated' => '1150723973',
    'message' => 'Het woord &quot;Samenvatting&quot;.'
  },
  'system template' => {
    'lastUpdated' => '1166436689',
    'message' => 'Collaboratie sjabloon'
  },
  'system template description' => {
    'lastUpdated' => '1147704684',
    'message' => 'Dit is het hoofdsjabloon voor de collaboratie asset.'
  },
  'thread approval workflow' => {
    'lastUpdated' => '1190027918',
    'message' => 'workflow Goedkeuring bericht (thread)'
  },
  'thread approval workflow description' => {
    'lastUpdated' => '1190027888',
    'message' => 'Kies een workflow om uit te voeren na het toevoegen van een nieuw bericht (thread). '
  },
  'thread template' => {
    'lastUpdated' => '1168960122',
    'message' => 'collaboratie systeem, draad sjabloon'
  },
  'thread template description' => {
    'lastUpdated' => '1147704638',
    'message' => 'Het sjabloon waarmee een draad getoond wordt. '
  },
  'threads/page' => {
    'lastUpdated' => '1166436607',
    'message' => 'Berichten per pagina'
  },
  'threads/page description' => {
    'lastUpdated' => '1147704589',
    'message' => 'Het aantal draden dat op elke pagina in het systeem sjabloon getoond wordt. Als dit nummer erg hoog is kan de pagina daardoor trager worden. '
  },
  'thumbnail' => {
    'lastUpdated' => '1147704505',
    'message' => 'Miniatuur'
  },
  'thumbnail size' => {
    'lastUpdated' => '1166436515',
    'message' => 'Grootte miniatuurafbeelding'
  },
  'thumbnail size help' => {
    'lastUpdated' => '1166192998',
    'message' => 'Stel de grootte van de miniatuurafbeeldingen in voor dit collaboratiesysteem. Wanneer je hier "0" instelt, zal standaard de grootte worden gebruikt zoals die is ingesteld onder "instellingen" uit het admin-menu. Het wijzigen van deze instelling zal er niet toe leiden dat eerder geplaatste afbeeldingen opnieuw worden geschaald. Om dit te bereiken moet iedere bijdrage opnieuw worden bewaard. '
  },
  'thumbnail.label' => {
    'lastUpdated' => '1150723992',
    'message' => 'Het woord &quot;Miniatuur&quot;.'
  },
  'timeSubmitted.human' => {
    'lastUpdated' => '1150099811',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De tijd waarop deze post was toegevoegd, in een normaal leesbaar formaat. </p></div>'
  },
  'timeUpdated.human' => {
    'lastUpdated' => '1150099836',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De tijd waarop deze post voor de laatste keer is vernieuwd, in een normaal leesbaar formaat.    </p></div>'
  },
  'title' => {
    'lastUpdated' => '1147187770',
    'message' => 'Titel'
  },
  'title.label' => {
    'lastUpdated' => '1150724007',
    'message' => 'Het woord &quot;Titel&quot;.'
  },
  'tmplVar status' => {
    'lastUpdated' => '1150102367',
    'message' => 'De status van deze post.'
  },
  'tmplVar thumbnail' => {
    'lastUpdated' => '1207832139',
    'message' => 'Als deze post bijlages heeft, is dit de URL van het miniatuur van de eerst bijlage die een afbeelding is. '
  },
  'tmplVar url' => {
    'lastUpdated' => '1150102438',
    'message' => 'De URL van deze post.'
  },
  'transfer karma' => {
    'lastUpdated' => '1147704495',
    'message' => 'Geef karma door'
  },
  'transferkarma.label' => {
    'lastUpdated' => '1257328386',
    'message' => 'De zinsnede "Geef karma door".'
  },
  'unarchive' => {
    'lastUpdated' => '1147704467',
    'message' => 'Haal uit het archief'
  },
  'unarchive all' => {
    'lastUpdated' => '1257328428',
    'message' => 'Haal alle draden uit het archief.'
  },
  'unarchive confirm' => {
    'lastUpdated' => '1257328483',
    'message' => 'Weet u het zeker? Alle draden na de "Archiveren na" tijdsinterval worden geherarchiveerd.'
  },
  'unlock' => {
    'lastUpdated' => '1147704444',
    'message' => 'Ontgrendelen'
  },
  'unlock.label' => {
    'lastUpdated' => '1150724026',
    'message' => 'Het woord &quot;Ontgrendelen&quot;.'
  },
  'unstick' => {
    'lastUpdated' => '1150724090',
    'message' => 'Niet meer bovenaan zetten'
  },
  'unstick.label' => {
    'lastUpdated' => '1150724107',
    'message' => 'De zinsnede &quot;Niet meer bovenaan zetten&quot;.'
  },
  'unsubscribe' => {
    'lastUpdated' => '1147704368',
    'message' => 'Uitschrijven'
  },
  'unsubscribe formEmail' => {
    'lastUpdated' => '1275487345',
    'message' => 'Een tekstformulier voor e-mail.'
  },
  'unsubscribe formFooter' => {
    'lastUpdated' => '1275487402',
    'message' => 'HTML code om het uitschrijfformulier mee te be&euml;indigen.'
  },
  'unsubscribe formHeader' => {
    'lastUpdated' => '1275487394',
    'message' => 'HTML code om het uitschrijfformulier mee te beginnen.'
  },
  'unsubscribe formMessage' => {
    'lastUpdated' => '1275487432',
    'message' => 'Geinternationaliseerde berichten, die de gebruiker de status laten zien.'
  },
  'unsubscribe formSubmit' => {
    'lastUpdated' => '1275487446',
    'message' => 'Een knop om het formulier mee in te zenden.'
  },
  'unsubscribe instructions' => {
    'lastUpdated' => '1275487474',
    'message' => 'Voer het e-mail adres in van de gebruiker die zich uit wil schrijven.'
  },
  'unsubscribe template' => {
    'lastUpdated' => '1275487484',
    'message' => 'Uitschrijfsjabloon'
  },
  'unsubscribe template hoverHelp' => {
    'lastUpdated' => '1275487524',
    'message' => 'Kies een sjabloon om een niet ingelogde gebruiker te helpen van het collabartie systeem of een draad daarin.'
  },
  'unsubscribe.label' => {
    'lastUpdated' => '1150724139',
    'message' => '<p>Het woord &quot;Uitschrijven&quot;.</p>'
  },
  'unsubscribe.url' => {
    'lastUpdated' => '1150101292',
    'message' => '<p>Een URL waar de huidige gebruiker uitgeschreven kan worden uit de asset.</p>'
  },
  'url' => {
    'lastUpdated' => '1147187934',
    'message' => 'URL'
  },
  'url.label' => {
    'lastUpdated' => '1150724164',
    'message' => 'De afkorting &quot;URL&quot;. '
  },
  'use captcha hover help' => {
    'lastUpdated' => '1190027819',
    'message' => 'Geef aan of gebruikers moeten bewijzen mensen te zijn door in te tikken wat er op een plaatje staat.'
  },
  'use captcha label' => {
    'lastUpdated' => '1190027789',
    'message' => 'Gebruik captcha bij post?'
  },
  'use preview' => {
    'lastUpdated' => '1166436348',
    'message' => 'Voorbeeldweergave?'
  },
  'use preview description' => {
    'lastUpdated' => '1207824267',
    'message' => 'Selecteer &quot;Ja&quot;, zodat een voorbeeld getoond wordt aan de gebruiker voordat deze zijn post toevoegt. Terwijl dit voorbeeld getoond wordt, kan de post nog bewerkt of teruggenomen worden. '
  },
  'user' => {
    'lastUpdated' => '1147187783',
    'message' => 'Gebruiker'
  },
  'user defined 1' => {
    'lastUpdated' => '1147704095',
    'message' => 'Gebruiker gedefini&amp;euml;erd als 1'
  },
  'user defined 2' => {
    'lastUpdated' => '1147704083',
    'message' => 'Gebruiker gedefini&amp;euml;erd als2'
  },
  'user defined 3' => {
    'lastUpdated' => '1147704070',
    'message' => 'Gebruiker gedefini&amp;euml;erd als3'
  },
  'user defined 4' => {
    'lastUpdated' => '1147704059',
    'message' => 'Gebruiker gedefini&amp;euml;erd als4'
  },
  'user defined 5' => {
    'lastUpdated' => '1147704044',
    'message' => 'Gebruiker gedefini&amp;euml;erd als 5'
  },
  'user.canPost' => {
    'lastUpdated' => '1207832472',
    'message' => '<p>Een conditionele functie die waar is als de huidige gebruiker posts kan toevoegen aan dit collaboratie systeem. </p>'
  },
  'user.canStartThread' => {
    'lastUpdated' => '1257328521',
    'message' => 'Een conditionele functie die waar is als de huidige gebruiker draden aan dit asset kan toevoegen.'
  },
  'user.hasRead' => {
    'lastUpdated' => '1150100062',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>Hiermee wordt aangeven of de gebruiker deze draad al (gedeeltelijk) heeft gelezen.</p></div>'
  },
  'user.isModerator' => {
    'lastUpdated' => '1150101150',
    'message' => '<p>Een conditionele functie die waar is als de huidige gebruiker een moderator is voor deze asset. </p>'
  },
  'user.isPoster' => {
    'lastUpdated' => '1150100043',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>Een voorwaarde die aangeeft of de huidige gebruiker deze post heeft toegevoegd.</p></div>'
  },
  'user.isSubscribed' => {
    'lastUpdated' => '1207833470',
    'message' => '<p>Een conditionele functie die waar is als de huidige gebruiker ingeschreven is bij deze collaboratie asset. </p>'
  },
  'user.isVisitor' => {
    'lastUpdated' => '1150099885',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>Een conditionele functie die &quot;waar&quot; geeft als de gebruiker een bezoeker is. </p></div>'
  },
  'user.label' => {
    'lastUpdated' => '1150724182',
    'message' => 'Het woord &quot;Gebruiker&quot;.'
  },
  'userProfile.url' => {
    'lastUpdated' => '1150099862',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>De URL van het profiel van de gebruiker&nbsp; die deze post heeft toegevoegd. </p></div>'
  },
  'views' => {
    'lastUpdated' => '1147703669',
    'message' => 'Aantal keren bekeken'
  },
  'views.label' => {
    'lastUpdated' => '1150724206',
    'message' => 'De zinsnede &quot;Aantal keren bekeken&quot;.'
  },
  'visitor' => {
    'lastUpdated' => '1147703439',
    'message' => 'Naam van de bezoeker'
  },
  'visitor cache timeout' => {
    'lastUpdated' => '1166436462',
    'message' => 'Cache timeout'
  },
  'visitor cache timeout help' => {
    'lastUpdated' => '1207824613',
    'message' => 'Deze asset wordt gecached voor het verhogen van de prestaties. Dit kan omdat alle bezoekers deze asset op dezelfde manier zien. Hoe lang moet deze asset in het cache geheugen opgeslagen worden? '
  },
  'visitorName.label' => {
    'lastUpdated' => '1150724245',
    'message' => 'Het woord &quot;Gebruikersnaam&quot;.'
  },
  'webMaster' => {
    'lastUpdated' => '1150100592',
    'message' => '<p>Het email adres van de technicus verantwoordelijk voor de RSS toevoer (optioneel veld).</p>'
  },
  'who posts' => {
    'lastUpdated' => '1320871123',
    'message' => 'Wie kan reacties plaatsen?'
  },
  'who posts description' => {
    'lastUpdated' => '1320871157',
    'message' => 'De groep die mag reageren op bijdragen, maar geen nieuwe bijdrage mag plaatsen.'
  },
  'who threads' => {
    'lastUpdated' => '1320871144',
    'message' => 'Wie kan nieuwe bijdragen plaatsen?'
  },
  'who threads description' => {
    'lastUpdated' => '1320871175',
    'message' => 'De groep die nieuwe bijdragen mag plaatsen.'
  }
}
;

1;
